@@ -8,7 +8,7 @@
  * Rancier <mephis5@softhome.net>. The Twofish code was taken from Doug 
  * Whiting's C implementation from www.counterpane.com.
  * 
- * $Id: ncrypt.c,v 1.2 2003/04/26 23:28:17 s-nomad Exp $
+ * $Id: ncrypt.c,v 1.4 2003/05/03 07:01:31 s-nomad Exp $
  */
 
 #include <stdio.h>
@@ -62,7 +62,7 @@ void initialize_crypto(char* pass)
     /* after hashing, erase the plaintext password instance from memory */
     guaranteed_memset(pass,0,strlen(pass));
 
-    if (ARGS.rijndael_given) r = makeKeyR(&keyInstR, direction, len, keyMaterial);
+    if (ARGS.aes_given || ARGS.rijndael_given) r = makeKeyR(&keyInstR, direction, len, keyMaterial);
     if (ARGS.serpent_given)  r = makeKeyS(&keyInstS, direction, len, keyMaterial);
     if (ARGS.twofish_given)
     {
@@ -84,7 +84,7 @@ void initialize_crypto(char* pass)
     }
 
     /* init the algo we are using */
-    if (ARGS.rijndael_given) r = cipherInitR(&cipherInst,  MODE_CBC, NULL);
+    if (ARGS.aes_given || ARGS.rijndael_given) r = cipherInitR(&cipherInst,  MODE_CBC, NULL);
     if (ARGS.serpent_given)  r = cipherInitS(&cipherInst,  MODE_ECB, NULL);
     if (ARGS.twofish_given)  r = cipherInitT(&cipherInstT, MODE_CBC, NULL);
     if (r != TRUE)
@@ -120,36 +120,17 @@ void check_for_lockable_memory()
 #endif
 
 
-int wipe()
+int wipe(int wipe_mode)
 {
     int i = 0;
-    if (ARGS.output_given && !ARGS.encrypt_wipe_given)
-    {
-        fprintf(stderr,"ERROR: `output' option invalid when wiping files\n");
-        return -1;
-    }
-    if (ARGS.wipe_given && ARGS.input_given)
-    {
-        fprintf(stderr,"ERROR: `input' option invalid when wiping files\n");
-        return -1;
-    }
-    if (ARGS.encrypt_wipe_given)
-    {
-        if (ARGS.input_given)
-	    wipe_file(ARGS.input_arg);
-	else
-	{
-		fprintf(stderr, "ERROR: wiping input file when encrypting will not work with STDIN\n");
-		return -1;
-	}
-    }
+    
+    if(ARGS.input_given)
+	    wipe_file(ARGS.input_arg,ARGS.verbose_given,wipe_mode);
     else for (i = 0 ; i < ARGS.inputs_num ; i++)
-	wipe_file(ARGS.inputs[i]);
+	wipe_file(ARGS.inputs[i],ARGS.verbose_given,wipe_mode);
     return 0;
 }
 
-
-
 int encrypt(FILE* ifp, FILE* ofp)
 {
     char* pass = get_encryption_password();
@@ -208,16 +189,16 @@ int main(int argc, char** argv)
 {
     FILE* ifp = NULL;
     FILE* ofp = NULL;
-    int rc = 0;
+    int rc = 0, wipe_mode = 0;
 
     PROGNAME = argv[0];
     if (cmdline_parser(argc,argv,&ARGS) != 0) exit(1);
 
-    if (!ARGS.rijndael_given && !ARGS.serpent_given && !ARGS.twofish_given)
+    if (!ARGS.aes_given && !ARGS.rijndael_given && !ARGS.serpent_given && !ARGS.twofish_given)
 	    ARGS.rijndael_given = 1;
     if (ARGS.verbose_given)
     {
-        if (ARGS.rijndael_given && ARGS.output_given)  printf("NOTE: aes given\n");
+        if ((ARGS.rijndael_given || ARGS.aes_given ) && ARGS.output_given)  printf("NOTE: aes (rijndael) given\n");
         if (ARGS.serpent_given  && ARGS.output_given)  printf("NOTE: serpent given\n");
         if (ARGS.twofish_given  && ARGS.output_given)  printf("NOTE: twofish given\n");
     }
@@ -226,13 +207,17 @@ int main(int argc, char** argv)
     check_for_lockable_memory();
 #endif
     
-    if (ARGS.wipe_given) return wipe();
-
-    ifp = determine_input_file();
-    ofp = determine_output_file();
+    if (ARGS.input_given) ifp = determine_input_file();
+    if (ARGS.output_given) ofp = determine_output_file();
+    
+    if (ARGS.wipe_given_gutmann) wipe_mode = WIPE_GUTMANN;
+    if (ARGS.wipe_given_military) wipe_mode = WIPE_MILITARY;
+    if ((ARGS.wipe_given_gutmann) && (ARGS.wipe_given_military)) wipe_mode = WIPE_BOTH;
+    if (ARGS.wipe_only) return wipe(wipe_mode);
 
     if (ARGS.encrypt_given) rc = encrypt(ifp,ofp);
-    if (ARGS.encrypt_wipe_given && rc == 0) rc = wipe();
+    
+    if (wipe_mode && (rc == 0)) rc = wipe(wipe_mode);
     if (ARGS.decrypt_given) rc = decrypt(ifp,ofp);
 
     fclose(ifp);
