@@ -1,11 +1,14 @@
+#ifndef _ncrypt_h_
+#define _ncrypt_h_
 /*  ncrypt.h  - adapted from several aes.h files for the algo's */
-/*  $Id: ncrypt.h,v 1.1.1.1 2003/02/15 02:50:28 s-nomad Exp $ */
+/*  $Id: ncrypt.h,v 1.1.1.1 2003/04/23 13:15:06 s-nomad Exp $ */
 
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include "rijndael-alg-fst.h"
 #include "platform.h"
+#include "cmdline.h"
 
 #define DIR_ENCRYPT     0    /*  Are we encrypting?  */
 #define DIR_DECRYPT     1    /*  Are we decrypting?  */
@@ -16,7 +19,9 @@
 #define TRUE            1
 #define FALSE           0
 #define BITSPERBLOCK  128    /* Default number of bits in a cipher block */
-#define VER       "0.5.5"    /* ncrypt prog version number */ 
+#define WIPE_GUTMANN	1
+#define WIPE_MILITARY	2
+#define WIPE_BOTH	3
 
 #define BAD_KEY_DIR         -1  /* Key direction invalid, eg unknown value */
 #define BAD_KEY_MAT         -2  /* Key material not of correct length */
@@ -193,3 +198,12 @@ int TableOp(int op);
 #define         BlockCopy(d,s)  { memcpy(d,s,BLOCK_SIZE/8); }
 #endif
 
+extern keyInstanceT keyInstT;
+extern keyInstanceS keyInstS;
+extern keyInstanceR keyInstR;
+extern cipherInstance cipherInst;
+extern cipherInstanceT cipherInstT;
+extern struct gengetopt_args_info ARGS;
+extern const char* PROGNAME;
+#endif
+
